@@ -1,11 +1,13 @@
-use crate::{ error::Result, exec::GenericExecutable };
+use crate::error::Result;
+use ezexec::ExecBuilder;
+use std::convert::TryInto;
 
 
 /// A choice dialogue
 #[derive(Debug)]
 pub struct DialogChoice {
     /// The underlying generic executable
-    exec: GenericExecutable
+    exec: ExecBuilder
 }
 impl DialogChoice {
     /// Creates a new choice dialog command
@@ -13,23 +15,21 @@ impl DialogChoice {
         where M: ToString, O: IntoIterator<Item = (OSA, OSB)>, OSA: ToString, OSB: ToString
     {
         // Build the CLI options
-        let mut cli_options = vec![
+        let mut args = vec![
             "--clear".to_string(), "--stdout".to_string(),
             "--menu".to_string(), message.to_string(), "0".to_string(), "0".to_string(), "0".to_string()
         ];
         for (tag, desc) in options {
-            cli_options.push(tag.to_string());
-            cli_options.push(desc.to_string());
+            args.push(tag.to_string());
+            args.push(desc.to_string());
         }
 
         // Create the executable
-        let dialog = GenericExecutable::find("dialog")?;
-        let exec = GenericExecutable::new(dialog, cli_options);
-        Ok(Self { exec })
+        Ok(Self { exec: ExecBuilder::with_name("dialog", args)? })
     }
     
     /// Shows the menu dialog and captures the input as string
     pub fn exec(self) -> Result<String> {
-        self.exec.exec_stringout()
+        Ok(self.exec.spawn_captured()?.try_into()?)
     }
 }
