@@ -1,22 +1,22 @@
-use crate::{ error::Result, exec::GenericExecutable };
+use crate::error::Result;
+use ezexec::ExecBuilder;
 
 
 /// A information dialog
 #[derive(Debug)]
 pub struct DialogInfo {
     /// The underlying generic executable
-    exec: GenericExecutable
+    exec: ExecBuilder
 }
 impl DialogInfo {
     /// Creates a new information dialog command
     pub fn new<T>(message: T) -> Result<Self> where T: AsRef<str> {
-        let dialog = GenericExecutable::find("dialog")?;
-        let exec = GenericExecutable::new(dialog, ["--stdout", "--infobox", message.as_ref(), "0", "0"]);
+        let exec = ExecBuilder::with_name("dialog", ["--stdout", "--infobox", message.as_ref(), "0", "0"])?;
         Ok(Self { exec })
     }
     
     /// Shows the information dialog
     pub fn exec(self) -> Result {
-        self.exec.exec()
+        Ok(self.exec.spawn_transparent()?.wait()?)
     }
 }
