@@ -1,17 +1,17 @@
-use crate::{ config::Config, error::Result, exec::GenericExecutable };
+use crate::{ config::Config, error::Result };
+use ezexec::ExecBuilder;
 
 
 /// Removes a stale lock on a restic repository
 #[derive(Debug)]
 pub struct ResticBreakLock {
     /// The underlying generic executable
-    exec: GenericExecutable
+    exec: ExecBuilder
 }
 impl ResticBreakLock {
     /// Creates a command to remove a stale lock on a restic repository
     pub fn new(config: &Config) -> Result<Self> {
-        let restic = GenericExecutable::find("restic")?;
-        let mut exec = GenericExecutable::new(restic, ["unlock"]);
+        let mut exec = ExecBuilder::with_name("restic", ["unlock"])?;
         exec.set_envs(config.to_env()?);
 
         Ok(Self { exec })
@@ -19,6 +19,6 @@ impl ResticBreakLock {
     
     /// Removes a stale lock on the restic repository
     pub fn exec(self) -> Result {
-        self.exec.exec()
+        Ok(self.exec.spawn_transparent()?.wait()?)
     }
 }
