@@ -1,30 +1,29 @@
-use crate::{ config::Config, error::Result, exec::GenericExecutable };
+use crate::{ config::Config, error::Result };
+use ezexec::ExecBuilder;
 
 
 /// Restores the latest snapshot
 #[derive(Debug)]
 pub struct ResticRestore {
     /// The underlying generic executable
-    exec: GenericExecutable
+    exec: ExecBuilder
 }
 impl ResticRestore {
     /// Creates a command to restore the latest snapshot with the given tags
-    pub fn new<S, I>(config: &Config, tags: I) -> Result<Self> where I: IntoIterator<Item = S>, S: ToString {
-        // Look for restic and concatenate the tags
-        let restic = GenericExecutable::find("restic")?;
-        let tags = tags.into_iter().map(|a| a.to_string()).collect::<Vec<_>>().join(",");
-        
+    pub fn new<S, I>(config: &Config, tags: I) -> Result<Self> where I: IntoIterator<Item = S>, S: ToString {        
         // Create the executable
-        let mut exec = GenericExecutable::new(restic, [
+        let tags = tags.into_iter().map(|a| a.to_string()).collect::<Vec<_>>().join(",");
+        let mut exec = ExecBuilder::with_name("restic", [
             "restore", "latest", "--target", "/",
             "--tag", &tags, "--path", &config.restic.dir
-        ]);
+        ])?;
         exec.set_envs(config.to_env()?);
+
         Ok(Self { exec })
     }
     
     /// Creates the backup/snapshot
     pub fn exec(self) -> Result {
-        self.exec.exec()
+        Ok(self.exec.spawn_transparent()?.wait()?)
     }
 }
